0.9.9 API documentation: matrix_integer.hpp Source File

| 0.9.9 API documentation

- Main Page
- Modules
- Files

- File List

matrix_integer.hpp
Go to the documentation of this file.
1
13 #pragma once
14
15 // Dependency:
16 #include "../mat2x2.hpp"
17 #include "../mat2x3.hpp"
18 #include "../mat2x4.hpp"
19 #include "../mat3x2.hpp"
20 #include "../mat3x3.hpp"
21 #include "../mat3x4.hpp"
22 #include "../mat4x2.hpp"
23 #include "../mat4x3.hpp"
24 #include "../mat4x4.hpp"
25
26 #if GLM_MESSAGES == GLM_ENABLE && !defined(GLM_EXT_INCLUDED)
27 # pragma message("GLM: GLM_GTC_matrix_integer extension included")
28 #endif
29
30 namespace glm
31 {
34
37 typedef mat<2, 2, int, highp> highp_imat2;
38
41 typedef mat<3, 3, int, highp> highp_imat3;
42
45 typedef mat<4, 4, int, highp> highp_imat4;
46
49 typedef mat<2, 2, int, highp> highp_imat2x2;
50
53 typedef mat<2, 3, int, highp> highp_imat2x3;
54
57 typedef mat<2, 4, int, highp> highp_imat2x4;
58
61 typedef mat<3, 2, int, highp> highp_imat3x2;
62
65 typedef mat<3, 3, int, highp> highp_imat3x3;
66
69 typedef mat<3, 4, int, highp> highp_imat3x4;
70
73 typedef mat<4, 2, int, highp> highp_imat4x2;
74
77 typedef mat<4, 3, int, highp> highp_imat4x3;
78
81 typedef mat<4, 4, int, highp> highp_imat4x4;
82
83
86 typedef mat<2, 2, int, mediump> mediump_imat2;
87
90 typedef mat<3, 3, int, mediump> mediump_imat3;
91
94 typedef mat<4, 4, int, mediump> mediump_imat4;
95
96
99 typedef mat<2, 2, int, mediump> mediump_imat2x2;
100
103 typedef mat<2, 3, int, mediump> mediump_imat2x3;
104
107 typedef mat<2, 4, int, mediump> mediump_imat2x4;
108
111 typedef mat<3, 2, int, mediump> mediump_imat3x2;
112
115 typedef mat<3, 3, int, mediump> mediump_imat3x3;
116
119 typedef mat<3, 4, int, mediump> mediump_imat3x4;
120
123 typedef mat<4, 2, int, mediump> mediump_imat4x2;
124
127 typedef mat<4, 3, int, mediump> mediump_imat4x3;
128
131 typedef mat<4, 4, int, mediump> mediump_imat4x4;
132
133
136 typedef mat<2, 2, int, lowp> lowp_imat2;
137
140 typedef mat<3, 3, int, lowp> lowp_imat3;
141
144 typedef mat<4, 4, int, lowp> lowp_imat4;
145
146
149 typedef mat<2, 2, int, lowp> lowp_imat2x2;
150
153 typedef mat<2, 3, int, lowp> lowp_imat2x3;
154
157 typedef mat<2, 4, int, lowp> lowp_imat2x4;
158
161 typedef mat<3, 2, int, lowp> lowp_imat3x2;
162
165 typedef mat<3, 3, int, lowp> lowp_imat3x3;
166
169 typedef mat<3, 4, int, lowp> lowp_imat3x4;
170
173 typedef mat<4, 2, int, lowp> lowp_imat4x2;
174
177 typedef mat<4, 3, int, lowp> lowp_imat4x3;
178
181 typedef mat<4, 4, int, lowp> lowp_imat4x4;
182
183
186 typedef mat<2, 2, uint, highp> highp_umat2;
187
190 typedef mat<3, 3, uint, highp> highp_umat3;
191
194 typedef mat<4, 4, uint, highp> highp_umat4;
195
198 typedef mat<2, 2, uint, highp> highp_umat2x2;
199
202 typedef mat<2, 3, uint, highp> highp_umat2x3;
203
206 typedef mat<2, 4, uint, highp> highp_umat2x4;
207
210 typedef mat<3, 2, uint, highp> highp_umat3x2;
211
214 typedef mat<3, 3, uint, highp> highp_umat3x3;
215
218 typedef mat<3, 4, uint, highp> highp_umat3x4;
219
222 typedef mat<4, 2, uint, highp> highp_umat4x2;
223
226 typedef mat<4, 3, uint, highp> highp_umat4x3;
227
230 typedef mat<4, 4, uint, highp> highp_umat4x4;
231
232
235 typedef mat<2, 2, uint, mediump> mediump_umat2;
236
239 typedef mat<3, 3, uint, mediump> mediump_umat3;
240
243 typedef mat<4, 4, uint, mediump> mediump_umat4;
244
245
248 typedef mat<2, 2, uint, mediump> mediump_umat2x2;
249
252 typedef mat<2, 3, uint, mediump> mediump_umat2x3;
253
256 typedef mat<2, 4, uint, mediump> mediump_umat2x4;
257
260 typedef mat<3, 2, uint, mediump> mediump_umat3x2;
261
264 typedef mat<3, 3, uint, mediump> mediump_umat3x3;
265
268 typedef mat<3, 4, uint, mediump> mediump_umat3x4;
269
272 typedef mat<4, 2, uint, mediump> mediump_umat4x2;
273
276 typedef mat<4, 3, uint, mediump> mediump_umat4x3;
277
280 typedef mat<4, 4, uint, mediump> mediump_umat4x4;
281
282
285 typedef mat<2, 2, uint, lowp> lowp_umat2;
286
289 typedef mat<3, 3, uint, lowp> lowp_umat3;
290
293 typedef mat<4, 4, uint, lowp> lowp_umat4;
294
295
298 typedef mat<2, 2, uint, lowp> lowp_umat2x2;
299
302 typedef mat<2, 3, uint, lowp> lowp_umat2x3;
303
306 typedef mat<2, 4, uint, lowp> lowp_umat2x4;
307
310 typedef mat<3, 2, uint, lowp> lowp_umat3x2;
311
314 typedef mat<3, 3, uint, lowp> lowp_umat3x3;
315
318 typedef mat<3, 4, uint, lowp> lowp_umat3x4;
319
322 typedef mat<4, 2, uint, lowp> lowp_umat4x2;
323
326 typedef mat<4, 3, uint, lowp> lowp_umat4x3;
327
330 typedef mat<4, 4, uint, lowp> lowp_umat4x4;
331
332 #if(defined(GLM_PRECISION_HIGHP_INT))
333 typedef highp_imat2 imat2;
334 typedef highp_imat3 imat3;
335 typedef highp_imat4 imat4;
336 typedef highp_imat2x2 imat2x2;
337 typedef highp_imat2x3 imat2x3;
338 typedef highp_imat2x4 imat2x4;
339 typedef highp_imat3x2 imat3x2;
340 typedef highp_imat3x3 imat3x3;
341 typedef highp_imat3x4 imat3x4;
342 typedef highp_imat4x2 imat4x2;
343 typedef highp_imat4x3 imat4x3;
344 typedef highp_imat4x4 imat4x4;
345 #elif(defined(GLM_PRECISION_LOWP_INT))
346 typedef lowp_imat2 imat2;
347 typedef lowp_imat3 imat3;
348 typedef lowp_imat4 imat4;
349 typedef lowp_imat2x2 imat2x2;
350 typedef lowp_imat2x3 imat2x3;
351 typedef lowp_imat2x4 imat2x4;
352 typedef lowp_imat3x2 imat3x2;
353 typedef lowp_imat3x3 imat3x3;
354 typedef lowp_imat3x4 imat3x4;
355 typedef lowp_imat4x2 imat4x2;
356 typedef lowp_imat4x3 imat4x3;
357 typedef lowp_imat4x4 imat4x4;
358 #else //if(defined(GLM_PRECISION_MEDIUMP_INT))
359
362 typedef mediump_imat2 imat2;
363
366 typedef mediump_imat3 imat3;
367
370 typedef mediump_imat4 imat4;
371
374 typedef mediump_imat2x2 imat2x2;
375
378 typedef mediump_imat2x3 imat2x3;
379
382 typedef mediump_imat2x4 imat2x4;
383
386 typedef mediump_imat3x2 imat3x2;
387
390 typedef mediump_imat3x3 imat3x3;
391
394 typedef mediump_imat3x4 imat3x4;
395
398 typedef mediump_imat4x2 imat4x2;
399
402 typedef mediump_imat4x3 imat4x3;
403
406 typedef mediump_imat4x4 imat4x4;
407 #endif//GLM_PRECISION
408
409 #if(defined(GLM_PRECISION_HIGHP_UINT))
410 typedef highp_umat2 umat2;
411 typedef highp_umat3 umat3;
412 typedef highp_umat4 umat4;
413 typedef highp_umat2x2 umat2x2;
414 typedef highp_umat2x3 umat2x3;
415 typedef highp_umat2x4 umat2x4;
416 typedef highp_umat3x2 umat3x2;
417 typedef highp_umat3x3 umat3x3;
418 typedef highp_umat3x4 umat3x4;
419 typedef highp_umat4x2 umat4x2;
420 typedef highp_umat4x3 umat4x3;
421 typedef highp_umat4x4 umat4x4;
422 #elif(defined(GLM_PRECISION_LOWP_UINT))
423 typedef lowp_umat2 umat2;
424 typedef lowp_umat3 umat3;
425 typedef lowp_umat4 umat4;
426 typedef lowp_umat2x2 umat2x2;
427 typedef lowp_umat2x3 umat2x3;
428 typedef lowp_umat2x4 umat2x4;
429 typedef lowp_umat3x2 umat3x2;
430 typedef lowp_umat3x3 umat3x3;
431 typedef lowp_umat3x4 umat3x4;
432 typedef lowp_umat4x2 umat4x2;
433 typedef lowp_umat4x3 umat4x3;
434 typedef lowp_umat4x4 umat4x4;
435 #else //if(defined(GLM_PRECISION_MEDIUMP_UINT))
436
439 typedef mediump_umat2 umat2;
440
443 typedef mediump_umat3 umat3;
444
447 typedef mediump_umat4 umat4;
448
451 typedef mediump_umat2x2 umat2x2;
452
455 typedef mediump_umat2x3 umat2x3;
456
459 typedef mediump_umat2x4 umat2x4;
460
463 typedef mediump_umat3x2 umat3x2;
464
467 typedef mediump_umat3x3 umat3x3;
468
471 typedef mediump_umat3x4 umat3x4;
472
475 typedef mediump_umat4x2 umat4x2;
476
479 typedef mediump_umat4x3 umat4x3;
480
483 typedef mediump_umat4x4 umat4x4;
484 #endif//GLM_PRECISION
485
487 }//namespace glm
glm::imat4x4
mediump_imat4x4 imat4x4
Signed integer 4x4 matrix.
Definition: matrix_integer.hpp:406
glm::imat2x2
mediump_imat2x2 imat2x2
Signed integer 2x2 matrix.
Definition: matrix_integer.hpp:374
glm::umat4
mediump_umat4 umat4
Unsigned integer 4x4 matrix.
Definition: matrix_integer.hpp:447
glm::umat4x2
mediump_umat4x2 umat4x2
Unsigned integer 4x2 matrix.
Definition: matrix_integer.hpp:475
glm::lowp_umat4x4
mat< 4, 4, uint, lowp > lowp_umat4x4
Low-qualifier unsigned integer 4x4 matrix.
Definition: matrix_integer.hpp:330
glm::mediump_imat4x2
mat< 4, 2, int, mediump > mediump_imat4x2
Medium-qualifier signed integer 4x2 matrix.
Definition: matrix_integer.hpp:123
glm::lowp_umat4
mat< 4, 4, uint, lowp > lowp_umat4
Low-qualifier unsigned integer 4x4 matrix.
Definition: matrix_integer.hpp:293
glm::highp_imat3x2
mat< 3, 2, int, highp > highp_imat3x2
High-qualifier signed integer 3x2 matrix.
Definition: matrix_integer.hpp:61
glm::highp_umat3x3
mat< 3, 3, uint, highp > highp_umat3x3
High-qualifier unsigned integer 3x3 matrix.
Definition: matrix_integer.hpp:214
glm::lowp_umat2x2
mat< 2, 2, uint, lowp > lowp_umat2x2
Low-qualifier unsigned integer 2x2 matrix.
Definition: matrix_integer.hpp:298
glm::umat3x3
mediump_umat3x3 umat3x3
Unsigned integer 3x3 matrix.
Definition: matrix_integer.hpp:467
glm::highp_umat2x4
mat< 2, 4, uint, highp > highp_umat2x4
High-qualifier unsigned integer 2x4 matrix.
Definition: matrix_integer.hpp:206
glm::umat3x2
mediump_umat3x2 umat3x2
Unsigned integer 3x2 matrix.
Definition: matrix_integer.hpp:463
glm::lowp_imat3x2
mat< 3, 2, int, lowp > lowp_imat3x2
Low-qualifier signed integer 3x2 matrix.
Definition: matrix_integer.hpp:161
glm::highp_umat3
mat< 3, 3, uint, highp > highp_umat3
High-qualifier unsigned integer 3x3 matrix.
Definition: matrix_integer.hpp:190
glm::mediump_imat4x3
mat< 4, 3, int, mediump > mediump_imat4x3
Medium-qualifier signed integer 4x3 matrix.
Definition: matrix_integer.hpp:127
glm::imat3
mediump_imat3 imat3
Signed integer 3x3 matrix.
Definition: matrix_integer.hpp:366
glm::mediump_imat2
mat< 2, 2, int, mediump > mediump_imat2
Medium-qualifier signed integer 2x2 matrix.
Definition: matrix_integer.hpp:86
glm::mediump_umat3x4
mat< 3, 4, uint, mediump > mediump_umat3x4
Medium-qualifier unsigned integer 3x4 matrix.
Definition: matrix_integer.hpp:268
glm::lowp_imat4x4
mat< 4, 4, int, lowp > lowp_imat4x4
Low-qualifier signed integer 4x4 matrix.
Definition: matrix_integer.hpp:181
glm::highp_imat2x4
mat< 2, 4, int, highp > highp_imat2x4
High-qualifier signed integer 2x4 matrix.
Definition: matrix_integer.hpp:57
glm::umat2x3
mediump_umat2x3 umat2x3
Unsigned integer 2x3 matrix.
Definition: matrix_integer.hpp:455
glm::lowp_imat4x3
mat< 4, 3, int, lowp > lowp_imat4x3
Low-qualifier signed integer 4x3 matrix.
Definition: matrix_integer.hpp:177
glm::lowp_umat3
mat< 3, 3, uint, lowp > lowp_umat3
Low-qualifier unsigned integer 3x3 matrix.
Definition: matrix_integer.hpp:289
glm::mediump_umat4x4
mat< 4, 4, uint, mediump > mediump_umat4x4
Medium-qualifier unsigned integer 4x4 matrix.
Definition: matrix_integer.hpp:280
glm::mediump_umat3x2
mat< 3, 2, uint, mediump > mediump_umat3x2
Medium-qualifier unsigned integer 3x2 matrix.
Definition: matrix_integer.hpp:260
glm::mediump_umat2x4
mat< 2, 4, uint, mediump > mediump_umat2x4
Medium-qualifier unsigned integer 2x4 matrix.
Definition: matrix_integer.hpp:256
glm::highp_imat4x4
mat< 4, 4, int, highp > highp_imat4x4
High-qualifier signed integer 4x4 matrix.
Definition: matrix_integer.hpp:81
glm::lowp_umat2x4
mat< 2, 4, uint, lowp > lowp_umat2x4
Low-qualifier unsigned integer 2x4 matrix.
Definition: matrix_integer.hpp:306
glm::imat4x3
mediump_imat4x3 imat4x3
Signed integer 4x3 matrix.
Definition: matrix_integer.hpp:402
glm::mediump_umat3x3
mat< 3, 3, uint, mediump > mediump_umat3x3
Medium-qualifier unsigned integer 3x3 matrix.
Definition: matrix_integer.hpp:264
glm::highp_imat2
mat< 2, 2, int, highp > highp_imat2
High-qualifier signed integer 2x2 matrix.
Definition: matrix_integer.hpp:37
glm::umat2
mediump_umat2 umat2
Unsigned integer 2x2 matrix.
Definition: matrix_integer.hpp:439
glm::lowp_umat3x4
mat< 3, 4, uint, lowp > lowp_umat3x4
Low-qualifier unsigned integer 3x4 matrix.
Definition: matrix_integer.hpp:318
glm::mediump_umat4x2
mat< 4, 2, uint, mediump > mediump_umat4x2
Medium-qualifier unsigned integer 4x2 matrix.
Definition: matrix_integer.hpp:272
glm::imat4x2
mediump_imat4x2 imat4x2
Signed integer 4x2 matrix.
Definition: matrix_integer.hpp:398
glm::mediump_imat2x3
mat< 2, 3, int, mediump > mediump_imat2x3
Medium-qualifier signed integer 2x3 matrix.
Definition: matrix_integer.hpp:103
glm::mediump_umat2
mat< 2, 2, uint, mediump > mediump_umat2
Medium-qualifier unsigned integer 2x2 matrix.
Definition: matrix_integer.hpp:235
glm::imat2
mediump_imat2 imat2
Signed integer 2x2 matrix.
Definition: matrix_integer.hpp:362
glm::mediump_umat4x3
mat< 4, 3, uint, mediump > mediump_umat4x3
Medium-qualifier unsigned integer 4x3 matrix.
Definition: matrix_integer.hpp:276
glm::mediump_imat3
mat< 3, 3, int, mediump > mediump_imat3
Medium-qualifier signed integer 3x3 matrix.
Definition: matrix_integer.hpp:90
glm::highp_umat2
mat< 2, 2, uint, highp > highp_umat2
High-qualifier unsigned integer 2x2 matrix.
Definition: matrix_integer.hpp:186
glm::imat3x4
mediump_imat3x4 imat3x4
Signed integer 3x4 matrix.
Definition: matrix_integer.hpp:394
glm::highp_umat3x2
mat< 3, 2, uint, highp > highp_umat3x2
High-qualifier unsigned integer 3x2 matrix.
Definition: matrix_integer.hpp:210
glm::highp_imat2x2
mat< 2, 2, int, highp > highp_imat2x2
High-qualifier signed integer 2x2 matrix.
Definition: matrix_integer.hpp:49
glm::highp_umat3x4
mat< 3, 4, uint, highp > highp_umat3x4
High-qualifier unsigned integer 3x4 matrix.
Definition: matrix_integer.hpp:218
glm::mediump_imat3x3
mat< 3, 3, int, mediump > mediump_imat3x3
Medium-qualifier signed integer 3x3 matrix.
Definition: matrix_integer.hpp:115
glm::highp_umat4x4
mat< 4, 4, uint, highp > highp_umat4x4
High-qualifier unsigned integer 4x4 matrix.
Definition: matrix_integer.hpp:230
glm::imat2x4
mediump_imat2x4 imat2x4
Signed integer 2x4 matrix.
Definition: matrix_integer.hpp:382
glm::umat2x4
mediump_umat2x4 umat2x4
Unsigned integer 2x4 matrix.
Definition: matrix_integer.hpp:459
glm::mediump_imat2x4
mat< 2, 4, int, mediump > mediump_imat2x4
Medium-qualifier signed integer 2x4 matrix.
Definition: matrix_integer.hpp:107
glm::lowp_imat2
mat< 2, 2, int, lowp > lowp_imat2
Low-qualifier signed integer 2x2 matrix.
Definition: matrix_integer.hpp:136
glm::lowp_imat4x2
mat< 4, 2, int, lowp > lowp_imat4x2
Low-qualifier signed integer 4x2 matrix.
Definition: matrix_integer.hpp:173
glm::lowp_umat4x3
mat< 4, 3, uint, lowp > lowp_umat4x3
Low-qualifier unsigned integer 4x3 matrix.
Definition: matrix_integer.hpp:326
glm::imat4
mediump_imat4 imat4
Signed integer 4x4 matrix.
Definition: matrix_integer.hpp:370
glm::imat3x2
mediump_imat3x2 imat3x2
Signed integer 3x2 matrix.
Definition: matrix_integer.hpp:386
glm::lowp_umat2x3
mat< 2, 3, uint, lowp > lowp_umat2x3
Low-qualifier unsigned integer 2x3 matrix.
Definition: matrix_integer.hpp:302
glm::mediump_imat3x2
mat< 3, 2, int, mediump > mediump_imat3x2
Medium-qualifier signed integer 3x2 matrix.
Definition: matrix_integer.hpp:111
glm::umat4x4
mediump_umat4x4 umat4x4
Unsigned integer 4x4 matrix.
Definition: matrix_integer.hpp:483
glm::highp_imat4x3
mat< 4, 3, int, highp > highp_imat4x3
High-qualifier signed integer 4x3 matrix.
Definition: matrix_integer.hpp:77
glm::umat4x3
mediump_umat4x3 umat4x3
Unsigned integer 4x3 matrix.
Definition: matrix_integer.hpp:479
glm::lowp_umat4x2
mat< 4, 2, uint, lowp > lowp_umat4x2
Low-qualifier unsigned integer 4x2 matrix.
Definition: matrix_integer.hpp:322
glm::lowp_umat3x2
mat< 3, 2, uint, lowp > lowp_umat3x2
Low-qualifier unsigned integer 3x2 matrix.
Definition: matrix_integer.hpp:310
glm::highp_umat2x2
mat< 2, 2, uint, highp > highp_umat2x2
High-qualifier unsigned integer 2x2 matrix.
Definition: matrix_integer.hpp:198
glm::lowp_imat3x3
mat< 3, 3, int, lowp > lowp_imat3x3
Low-qualifier signed integer 3x3 matrix.
Definition: matrix_integer.hpp:165
glm::highp_imat3x3
mat< 3, 3, int, highp > highp_imat3x3
High-qualifier signed integer 3x3 matrix.
Definition: matrix_integer.hpp:65
glm::mediump_umat2x3
mat< 2, 3, uint, mediump > mediump_umat2x3
Medium-qualifier unsigned integer 2x3 matrix.
Definition: matrix_integer.hpp:252
glm::highp_umat4x2
mat< 4, 2, uint, highp > highp_umat4x2
High-qualifier unsigned integer 4x2 matrix.
Definition: matrix_integer.hpp:222
glm::lowp_umat3x3
mat< 3, 3, uint, lowp > lowp_umat3x3
Low-qualifier unsigned integer 3x3 matrix.
Definition: matrix_integer.hpp:314
glm::imat2x3
mediump_imat2x3 imat2x3
Signed integer 2x3 matrix.
Definition: matrix_integer.hpp:378
glm::lowp_imat2x3
mat< 2, 3, int, lowp > lowp_imat2x3
Low-qualifier signed integer 2x3 matrix.
Definition: matrix_integer.hpp:153
glm::highp_umat4
mat< 4, 4, uint, highp > highp_umat4
High-qualifier unsigned integer 4x4 matrix.
Definition: matrix_integer.hpp:194
glm::highp_imat3
mat< 3, 3, int, highp > highp_imat3
High-qualifier signed integer 3x3 matrix.
Definition: matrix_integer.hpp:41
glm::mediump_umat3
mat< 3, 3, uint, mediump > mediump_umat3
Medium-qualifier unsigned integer 3x3 matrix.
Definition: matrix_integer.hpp:239
glm::mediump_imat2x2
mat< 2, 2, int, mediump > mediump_imat2x2
Medium-qualifier signed integer 2x2 matrix.
Definition: matrix_integer.hpp:99
glm::highp_imat2x3
mat< 2, 3, int, highp > highp_imat2x3
High-qualifier signed integer 2x3 matrix.
Definition: matrix_integer.hpp:53
glm::highp_imat4x2
mat< 4, 2, int, highp > highp_imat4x2
High-qualifier signed integer 4x2 matrix.
Definition: matrix_integer.hpp:73
glm::lowp_imat3x4
mat< 3, 4, int, lowp > lowp_imat3x4
Low-qualifier signed integer 3x4 matrix.
Definition: matrix_integer.hpp:169
glm::umat3
mediump_umat3 umat3
Unsigned integer 3x3 matrix.
Definition: matrix_integer.hpp:443
glm::lowp_imat2x2
mat< 2, 2, int, lowp > lowp_imat2x2
Low-qualifier signed integer 2x2 matrix.
Definition: matrix_integer.hpp:149
glm::highp_umat2x3
mat< 2, 3, uint, highp > highp_umat2x3
High-qualifier unsigned integer 2x3 matrix.
Definition: matrix_integer.hpp:202
glm::highp_imat4
mat< 4, 4, int, highp > highp_imat4
High-qualifier signed integer 4x4 matrix.
Definition: matrix_integer.hpp:45
glm::lowp_imat2x4
mat< 2, 4, int, lowp > lowp_imat2x4
Low-qualifier signed integer 2x4 matrix.
Definition: matrix_integer.hpp:157
glm::mediump_imat3x4
mat< 3, 4, int, mediump > mediump_imat3x4
Medium-qualifier signed integer 3x4 matrix.
Definition: matrix_integer.hpp:119
glm::mediump_imat4x4
mat< 4, 4, int, mediump > mediump_imat4x4
Medium-qualifier signed integer 4x4 matrix.
Definition: matrix_integer.hpp:131
glm::mediump_imat4
mat< 4, 4, int, mediump > mediump_imat4
Medium-qualifier signed integer 4x4 matrix.
Definition: matrix_integer.hpp:94
glm::imat3x3
mediump_imat3x3 imat3x3
Signed integer 3x3 matrix.
Definition: matrix_integer.hpp:390
glm::lowp_imat3
mat< 3, 3, int, lowp > lowp_imat3
Low-qualifier signed integer 3x3 matrix.
Definition: matrix_integer.hpp:140
glm::lowp_umat2
mat< 2, 2, uint, lowp > lowp_umat2
Low-qualifier unsigned integer 2x2 matrix.
Definition: matrix_integer.hpp:285
glm::highp_umat4x3
mat< 4, 3, uint, highp > highp_umat4x3
High-qualifier unsigned integer 4x3 matrix.
Definition: matrix_integer.hpp:226
glm::umat2x2
mediump_umat2x2 umat2x2
Unsigned integer 2x2 matrix.
Definition: matrix_integer.hpp:451
glm::mediump_umat4
mat< 4, 4, uint, mediump > mediump_umat4
Medium-qualifier unsigned integer 4x4 matrix.
Definition: matrix_integer.hpp:243
glm::lowp_imat4
mat< 4, 4, int, lowp > lowp_imat4
Low-qualifier signed integer 4x4 matrix.
Definition: matrix_integer.hpp:144
glm::umat3x4
mediump_umat3x4 umat3x4
Unsigned integer 3x4 matrix.
Definition: matrix_integer.hpp:471
glm::highp_imat3x4
mat< 3, 4, int, highp > highp_imat3x4
High-qualifier signed integer 3x4 matrix.
Definition: matrix_integer.hpp:69
glm::mediump_umat2x2
mat< 2, 2, uint, mediump > mediump_umat2x2
Medium-qualifier unsigned integer 2x2 matrix.
Definition: matrix_integer.hpp:248
glm
Definition: common.hpp:20